==> uimaj_2.10.2.orig.tar.xz: uimaj-2.10.2/uimaj-ep-cas-editor/src/main/java/org/apache/uima/caseditor/editor/util/UimaUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.editor.util;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.uima.cas.FeatureStructure;
import org.apache.uima.cas.text.AnnotationFS;

/**
 * TODO: add javadoc here
 */
public class UimaUtil {
  /**
   * Casts a {@link FeatureStructure} collection to an {@link AnnotationFS} collection.
   *
   * @param annotations
   * @return the {@link AnnotationFS} collection
   */
  public static Collection<FeatureStructure> cast(Collection<AnnotationFS> annotations) {
    Collection<FeatureStructure> structures = new ArrayList<FeatureStructure>(annotations.size());

    for (AnnotationFS annotation : annotations) {
      structures.add(annotation);
    }

    return structures;
  }
}

==> uimaj_2.10.4.orig.tar.xz: uimaj-2.10.4/uimaj-ep-cas-editor/src/main/java/org/apache/uima/caseditor/editor/util/UimaUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.editor.util;

import java.util.ArrayList;
import java.util.Collection;

import org.apache.uima.cas.FeatureStructure;
import org.apache.uima.cas.text.AnnotationFS;


/**
 * TODO: add javadoc here.
 */
public class UimaUtil {
  
  /**
   * Casts a {@link FeatureStructure} collection to an {@link AnnotationFS} collection.
   *
   * @param annotations the annotations
   * @return the {@link AnnotationFS} collection
   */
  public static Collection<FeatureStructure> cast(Collection<AnnotationFS> annotations) {
    Collection<FeatureStructure> structures = new ArrayList<FeatureStructure>(annotations.size());

    for (AnnotationFS annotation : annotations) {
      structures.add(annotation);
    }

    return structures;
  }
}
